@@ -30,6 +30,7 @@ from gpt_index.indices.query.schema import QueryConfig, QueryMode
 from gpt_index.indices.struct_store.sql import GPTSQLStructStoreIndex
 from gpt_index.indices.tree import GPTTreeIndex
 from gpt_index.indices.vector_store import (
+    GPTChromaIndex,
     GPTFaissIndex,
     GPTPineconeIndex,
     GPTQdrantIndex,
@@ -58,6 +59,7 @@ from gpt_index.prompts.prompts import (
 # readers
 from gpt_index.readers import (
     BeautifulSoupWebReader,
+    ChromaReader,
     DiscordReader,
     Document,
     FaissReader,
@@ -96,6 +98,7 @@ __all__ = [
     "GPTWeaviateIndex",
     "GPTPineconeIndex",
     "GPTQdrantIndex",
+    "GPTChromaIndex",
     "GPTSQLStructStoreIndex",
     "Prompt",
     "LangchainEmbedding",
@@ -120,6 +123,7 @@ __all__ = [
     "StringIterableReader",
     "WeaviateReader",
     "FaissReader",
+    "ChromaReader",
     "PineconeReader",
     "QdrantReader",
     "DiscordReader",
