@@ -335,6 +335,20 @@ class QdrantIndexStruct(IndexStruct):
         return "qdrant"
 
 
+@dataclass
+class ChromaIndexStruct(IndexStruct):
+    """An index struct for Chroma.
+
+    Docs are stored in Chroma directly.
+
+    """
+
+    @classmethod
+    def get_type(cls) -> str:
+        """Get type."""
+        return "chroma"
+
+
 @dataclass
 class KG(IndexStruct):
     """A table of keywords mapping keywords to text chunks."""
