@@ -7,7 +7,6 @@ from dataclasses_json import DataClassJsonMixin
 
 from gpt_index.data_structs.data_structs import IndexStruct
 from gpt_index.readers.schema.base import Document
-from gpt_index.utils import get_new_id
 
 DOC_TYPE = Union[IndexStruct, Document]
 
@@ -73,30 +72,22 @@ class DocumentStore(DataClassJsonMixin):
         obj.add_documents(docs)
         return obj
 
-    def get_new_id(self) -> str:
-        """Get a new ID."""
-        return get_new_id(set(self.docs.keys()))
-
     def update_docstore(self, other: "DocumentStore") -> None:
         """Update docstore."""
         self.docs.update(other.docs)
 
-    def add_documents(self, docs: List[DOC_TYPE], generate_id: bool = True) -> None:
-        """Add a document to the store.
-
-        If generate_id = True, then generate id for doc if doc_id doesn't exist.
-
-        """
+    def add_documents(self, docs: List[DOC_TYPE], allow_update: bool = False) -> None:
+        """Add a document to the store."""
         for doc in docs:
             if doc.is_doc_id_none:
-                if generate_id:
-                    doc.doc_id = self.get_new_id()
-                else:
-                    raise ValueError(
-                        "doc_id not set (to generate id, please set generate_id=True)."
-                    )
+                raise ValueError("doc_id not set")
 
             # NOTE: doc could already exist in the store, but we overwrite it
+            if not allow_update and self.document_exists(doc.get_doc_id()):
+                raise ValueError(
+                    f"doc_id {doc.get_doc_id()} already exists. "
+                    "Set allow_update to True to overwrite."
+                )
             self.docs[doc.get_doc_id()] = doc
 
     def get_document(self, doc_id: str, raise_error: bool = True) -> Optional[DOC_TYPE]:
