@@ -11,7 +11,7 @@ from gpt_index.data_structs.data_structs import IndexStruct, Node
 from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.indices.base import DOCUMENTS_INPUT, BaseGPTIndex
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
-from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
+from gpt_index.langchain_helpers.text_splitter import TextSplitter
 from gpt_index.prompts.default_prompts import DEFAULT_TEXT_QA_PROMPT
 from gpt_index.prompts.prompts import QuestionAnswerPrompt
 from gpt_index.schema import BaseDocument
@@ -37,6 +37,7 @@ class BaseGPTVectorStoreIndex(BaseGPTIndex[BID], Generic[BID]):
         text_qa_template: Optional[QuestionAnswerPrompt] = None,
         llm_predictor: Optional[LLMPredictor] = None,
         embed_model: Optional[BaseEmbedding] = None,
+        text_splitter: Optional[TextSplitter] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize params."""
@@ -46,13 +47,9 @@ class BaseGPTVectorStoreIndex(BaseGPTIndex[BID], Generic[BID]):
             index_struct=index_struct,
             llm_predictor=llm_predictor,
             embed_model=embed_model,
+            text_splitter=text_splitter,
             **kwargs,
         )
-        # NOTE: when building the vector store index, text_qa_template is not partially
-        # formatted because we don't know the query ahead of time.
-        self._text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
-            self.text_qa_template, 1
-        )
 
     def _get_node_embedding_tups(
         self, nodes: List[Node], existing_node_ids: Set
@@ -90,20 +87,25 @@ class BaseGPTVectorStoreIndex(BaseGPTIndex[BID], Generic[BID]):
         self,
         index_struct: BID,
         document: BaseDocument,
-        text_splitter: TokenTextSplitter,
     ) -> None:
         """Add document to index."""
 
-    def _build_index_from_documents(self, documents: Sequence[BaseDocument]) -> BID:
-        """Build index from documents."""
-        text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
+    def _build_fallback_text_splitter(self) -> TextSplitter:
+        # if not specified, use "smart" text splitter to ensure chunks fit in prompt
+        return self._prompt_helper.get_text_splitter_given_prompt(
             self.text_qa_template, 1
         )
+
+    def _build_index_from_documents(
+        self,
+        documents: Sequence[BaseDocument],
+    ) -> BID:
+        """Build index from documents."""
         index_struct = self.index_struct_cls()
         for d in documents:
-            self._add_document_to_index(index_struct, d, text_splitter)
+            self._add_document_to_index(index_struct, d)
         return index_struct
 
     def _insert(self, document: BaseDocument, **insert_kwargs: Any) -> None:
         """Insert a document."""
-        self._add_document_to_index(self._index_struct, document, self._text_splitter)
+        self._add_document_to_index(self._index_struct, document)
