@@ -16,7 +16,7 @@ from gpt_index.indices.query.schema import QueryMode
 from gpt_index.indices.query.vector_store.faiss import GPTFaissIndexQuery
 from gpt_index.indices.vector_store.base import BaseGPTVectorStoreIndex
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
-from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
+from gpt_index.langchain_helpers.text_splitter import TextSplitter
 from gpt_index.prompts.prompts import QuestionAnswerPrompt
 from gpt_index.schema import BaseDocument
 
@@ -53,6 +53,7 @@ class GPTFaissIndex(BaseGPTVectorStoreIndex[IndexDict]):
         llm_predictor: Optional[LLMPredictor] = None,
         faiss_index: Optional[Any] = None,
         embed_model: Optional[BaseEmbedding] = None,
+        text_splitter: Optional[TextSplitter] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize params."""
@@ -79,6 +80,7 @@ class GPTFaissIndex(BaseGPTVectorStoreIndex[IndexDict]):
             text_qa_template=text_qa_template,
             llm_predictor=llm_predictor,
             embed_model=embed_model,
+            text_splitter=text_splitter,
             **kwargs,
         )
 
@@ -94,10 +96,9 @@ class GPTFaissIndex(BaseGPTVectorStoreIndex[IndexDict]):
         self,
         index_struct: IndexDict,
         document: BaseDocument,
-        text_splitter: TokenTextSplitter,
     ) -> None:
         """Add document to index."""
-        nodes = self._get_nodes_from_document(document, text_splitter)
+        nodes = self._get_nodes_from_document(document)
 
         id_node_embed_tups = self._get_node_embedding_tups(nodes, set())
 
