@@ -23,6 +23,7 @@ def download_loader(
     loader_class: str,
     loader_hub_url: str = LOADER_HUB_URL,
     refresh_cache: Optional[bool] = False,
+    use_gpt_index_import: bool = False,
 ) -> BaseReader:
     """Download a single loader from the Loader Hub.
 
@@ -31,6 +32,11 @@ def download_loader(
             such as `SimpleWebPageReader`.
         refresh_cache: If true, the local cache will be skipped and the
             loader will be fetched directly from the remote repo.
+        use_gpt_index_import: If true, the loader files will use
+            gpt_index as the base dependency. By default (False),
+            the loader files use llama_index as the base dependency.
+            NOTE: this is a temporary workaround while we fully migrate all usages
+            to llama_index.
 
     Returns:
         A Loader.
@@ -70,8 +76,14 @@ def download_loader(
 
     if refresh_cache or not os.path.exists(loader_path):
         response = requests.get(f"{loader_hub_url}/{loader_id}/base.py")
+        response_text = response.text
+        if use_gpt_index_import:
+            response_text = response_text.replace(
+                "import llama_index", "import gpt_index"
+            )
+            response_text = response_text.replace("from llama_index", "from gpt_index")
         with open(loader_path, "w") as f:
-            f.write(response.text)
+            f.write(response_text)
 
     if not os.path.exists(requirements_path):
         response = requests.get(f"{loader_hub_url}/{loader_id}/requirements.txt")
